# Copy Relative Path

[![PyPI](https://img.shields.io/pypi/v/jupyterlab-copy-relative-path)](https://pypi.org/project/jupyterlab-copy-relative-path/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/jupyterlab-copy-relative-path)](https://anaconda.org/conda-forge/jupyterlab-copy-relative-path)

> Adds **'Copy Relative Path'** to a context menu of JupyterLab tabs and file browser items.

This extension would be useful when specifying a file or a directory from a notebook. The path is relative to an active document; the button will hide when an active window does not provide a reference path; i.e. when a Launch page or a Console window is active.

![copy relative path demo](https://github.com/yamaton/jupyterlab_copy_relative_path/raw/main/preview.png)

# Install

Install with `pip`.

```shell
pip install jupyterlab-copy-relative-path
```

Or, via `conda-forge`.

```shell
conda install -c conda-forge jupyterlab-copy-relative-path
```
